@@ -65,6 +65,7 @@ import Control.Monad (when, unless)
 import Data.Monoid (mconcat)
 import Data.List (isSuffixOf)
 import Control.Arrow (second)
+import Text.Shakespeare (VarType)
 
 -- |
 --
@@ -219,6 +220,9 @@ parseComment = do
 
 luciusFile :: FilePath -> Q Exp
 luciusFile fp = do
+#ifdef GHC_7_4
+    qAddDependentFile fp
+#endif
     contents <- fmap TL.unpack $ qRunIO $ readUtf8File fp
     luciusFromString contents
 
